Module: Ragnar::TopicModeling
- Defined in:
- lib/ragnar/topic_modeling.rb
Constant Summary collapse
- Topic =
Re-export Topical classes for backward compatibility
Topical::Topic
- Engine =
Topical::Engine
- Metrics =
Re-export metrics module
Topical::Metrics
Class Method Summary collapse
-
.extract(embeddings:, documents:, **options) ⇒ Object
Extract topics from embeddings and documents (simple interface).
-
.new(**options) ⇒ Object
Convenience method to create a new topic modeling engine.
Class Method Details
.extract(embeddings:, documents:, **options) ⇒ Object
Extract topics from embeddings and documents (simple interface)
23 24 25 |
# File 'lib/ragnar/topic_modeling.rb', line 23 def self.extract(embeddings:, documents:, **) Topical.extract(embeddings: , documents: documents, **) end |
.new(**options) ⇒ Object
Convenience method to create a new topic modeling engine
18 19 20 |
# File 'lib/ragnar/topic_modeling.rb', line 18 def self.new(**) Topical::Engine.new(**) end |